#!/bin/sh

#
# get the VPD 0x80 page which is ASCII encoded using
# the scsi_id command - it appears that the scsi_id command
# outputs also the content of other vpd pages
#
# >scsi_id -g -d /dev/sdc -s /block/sdc -p 0x80
#
# SIET     VIRTUAL-DISK   AMHDSK-071129-00
# SRaidWeb.Com            000056189HP0103
#
# and we make a device name that starts with sd- followed by the
# the serial number
#
# input parameter is 'sdc' for example
#
# Steffen Plotner
#

function logmsg
{
	echo "$DEV: $1" | logger -t udev_iscsi_disk_sn
}

DEV="$1"
logmsg "DEV=$DEV"

#
# get serial number using scsi_id tool
#
CMD="/sbin/scsi_id -g -p 0x80 -s /block/$DEV 2> /dev/null"
logmsg "cmd: $CMD"

#
# raw scsi_id 
#
OUT=$($CMD)
logmsg "scsi_id: $OUT"

#
# scsi_sn starts at 24th position
#
OUT=${OUT:24}
logmsg "scsi_sn: $OUT"

#
# ditch all spaces (iet uses 4 spaces as a default, i.e. no serial number)
#
OUT=$(echo "$OUT" | sed -e 's/ //g')

if [ -n "$OUT" ]; then
	#
	# make safe
	#
	OUT=$(echo "$OUT" | sed -e 's/[^A-Z0-9_-]//g')
	logmsg "safe scsi_sn: $OUT"

	#
	# prefix with sd- so vmware server is happy
	#
	OUT="sd-$OUT"
	logmsg "/dev scsi_sn: /dev/$OUT"
fi

echo "$OUT"

exit 0

